@@ -4,7 +4,7 @@ use warnings;
 use strict;
 use 5.10.1;
 
-our $VERSION = '0.006';
+our $VERSION = '0.007';
 use Exporter 'import';
 our @EXPORT_OK = qw( choose_a_directory choose_a_number choose_a_subset choose_multi insert_sep
                      length_longest print_hash term_size unicode_sprintf unicode_trim util_readline );
@@ -369,7 +369,6 @@ sub print_hash {
             push @vals, $val;
         }
     }
-    return            @vals if         wantarray;
     return join "\n", @vals if defined wantarray;
     choose(
         [ @vals ],
@@ -497,7 +496,7 @@ Term::Choose::Util - CLI related functions.
 
 =head1 VERSION
 
-Version 0.006
+Version 0.007
 
 =cut
 
@@ -881,9 +880,8 @@ I<Length> means here number of print columns as returned by the C<columns> metho
 
 =head2 print_hash
 
-Prints a simple hash to STDOUT (or STDERR if the output is redirected) if called in void context. In scalar context
-I<print_hash> returns the formatted hash as a string; in list context it is returned a list - the formatted hash split up
-on newlines.
+Prints a simple hash to STDOUT (or to STDERR if the output is redirected) if called in void context. If not called in
+void context, I<print_hash> returns the formatted hash as a string.
 
 Nested hashes are not supported. If the hash has more keys than the terminal rows the output is divided up on several
 pages. The user can scroll through the single lines of the hash. In void context the output of the hash is closed when
